Ph1data: The measurement of snowfall in inches for the Phase I process

Description Format

Description

A dataset containing the measurement of snowfall in inches for the Phase I process. The variables are as follows:

Format

A data frame with 82 rows and 4 variables:

Year

The year of snowfall season

Jan

The snowfall in January

Feb

The snowfall in Feburary

Mar

The snowfall in March


bolus123/PH2XBAR documentation built on Aug. 5, 2020, 11:50 a.m.